package de.ozgcloud.eingang.xta;

import java.io.File;
import java.io.InputStream;
import java.math.BigInteger;
import java.nio.charset.StandardCharsets;

import org.apache.commons.io.FileUtils;

import lombok.SneakyThrows;

class XtaFileTestFactory {

	static final String NAME = "Test_File";
	static final String CONTENT = "slkafj3jifsdasx";

	static XtaFile create() {
		return createBuilder().build();
	}

	static XtaFile.XtaFileBuilder createBuilder() {
		return XtaFile.builder().name(NAME).file(createFile());
	}

	@SneakyThrows
	private static File createFile() {
		File tFile = File.createTempFile("test", "txt");
		tFile.deleteOnExit();

		FileUtils.write(tFile, CONTENT, StandardCharsets.UTF_8);

		return tFile;
	}

	@SneakyThrows
	static XtaFile withFileContent(InputStream stream, String fileName) {
		File tFile = File.createTempFile(fileName, ".zip");
		tFile.deleteOnExit();

		FileUtils.copyInputStreamToFile(stream, tFile);
		return createBuilder().name(fileName).size(BigInteger.valueOf(tFile.length())).file(tFile).build();
	}
}
